# Pics2Word

A command line program to copy pictures into a word document.

Usage can be found using "pics2word -h help"

TODO tasks:

High Priority:
    Features: 
    - Allow pictures to be implemented into a table
    Bug Fix:
    - Fix error with "-pw" & "-ph" commands showing "OverflowError: int too large to convert to float"

Low Priority:
    Features:
    - Use Docopt module to make arg parsing simpler and to a more modern standard
    - Implement a logger to aid with debugging
    Bug Fix:
    - More error checking, throw meaningful exceptions to aid with debugging
